@@ -1,7 +1,7 @@
-/* 
+/*
  * $Id$
  *
- * Helper functions related to fetching process information. Used by _psutil_mswindows 
+ * Helper functions related to fetching process information. Used by _psutil_mswindows
  * module methods.
  */
 
@@ -13,10 +13,10 @@
 #include "process_info.h"
 
 
-/* 
- * NtQueryInformationProcess code taken from 
+/*
+ * NtQueryInformationProcess code taken from
  *
- *     http://wj32.wordpress.com/2009/01/24/howto-get-the-command-line-of-processes/
+ * http://wj32.wordpress.com/2009/01/24/howto-get-the-command-line-of-processes/
  *
  * typedefs needed to compile against ntdll functions not exposted in the API
  */
@@ -48,7 +48,7 @@ typedef struct _PROCESS_BASIC_INFORMATION
 } PROCESS_BASIC_INFORMATION, *PPROCESS_BASIC_INFORMATION;
 
 
-//fetch the PEB base address from NtQueryInformationProcess()
+// fetch the PEB base address from NtQueryInformationProcess()
 PVOID GetPebAddress(HANDLE ProcessHandle)
 {
     _NtQueryInformationProcess NtQueryInformationProcess =
@@ -72,10 +72,10 @@ DWORD* get_pids(DWORD *numberOfReturnedPIDs){
 	/* Stores the actual array */
 	DWORD *procArray = NULL;
 	DWORD procArrayByteSz;
-	
+
     /* Stores the byte size of the returned array from enumprocesses */
 	DWORD enumReturnSz = 0;
-	
+
 	do {
 		free(procArray);
 
@@ -111,8 +111,8 @@ int pid_is_running(DWORD pid)
 {
     HANDLE hProcess;
     DWORD exitCode;
-    
-    //Special case for PID 0 System Idle Process
+
+    // Special case for PID 0 System Idle Process
     if (pid == 0) {
         return 1;
     }
@@ -123,11 +123,12 @@ int pid_is_running(DWORD pid)
 
     hProcess = handle_from_pid(pid);
     if (NULL == hProcess) {
-        if (GetLastError() == ERROR_INVALID_PARAMETER) { //invalid parameter is no such process
-            return 0; 
+        // invalid parameter is no such process
+        if (GetLastError() == ERROR_INVALID_PARAMETER) {
+            return 0;
         }
 
-        //access denied obviously means there's a process to deny access to...
+        // access denied obviously means there's a process to deny access to...
         if (GetLastError() == ERROR_ACCESS_DENIED) {
             return 1;
         }
@@ -140,7 +141,7 @@ int pid_is_running(DWORD pid)
         return (exitCode == STILL_ACTIVE);
     }
 
-    //access denied means there's a process there so we'll assume it's running
+    // access denied means there's a process there so we'll assume it's running
     if (GetLastError() == ERROR_ACCESS_DENIED) {
         return 1;
     }
@@ -155,10 +156,11 @@ int pid_in_proclist(DWORD pid)
     DWORD *proclist = NULL;
     DWORD numberOfReturnedPIDs;
     DWORD i;
-    
+
     proclist = get_pids(&numberOfReturnedPIDs);
     if (NULL == proclist) {
-		PyErr_SetString(PyExc_RuntimeError, "get_pids() failed for pid_in_proclist()");
+		PyErr_SetString(PyExc_RuntimeError,
+                        "get_pids() failed for pid_in_proclist()");
         return -1;
     }
 
@@ -174,10 +176,11 @@ int pid_in_proclist(DWORD pid)
 }
 
 
-//Get a process handle from a pid with PROCESS_QUERY_INFORMATION rights
+// Get a process handle from a pid with PROCESS_QUERY_INFORMATION rights
 HANDLE handle_from_pid(DWORD pid)
 {
-    HANDLE hProcess = OpenProcess(PROCESS_QUERY_INFORMATION | PROCESS_VM_READ, FALSE, pid);
+    HANDLE hProcess = OpenProcess(PROCESS_QUERY_INFORMATION | PROCESS_VM_READ,
+                                  FALSE, pid);
     /*
     if (NULL == hProcess) {
         hProcess = OpenProcess(PROCESS_QUERY_INFORMATION, FALSE, pid);
@@ -187,8 +190,8 @@ HANDLE handle_from_pid(DWORD pid)
 }
 
 
-//Check exit code from a process handle. Return FALSE on an error also
-BOOL is_running(HANDLE hProcess) 
+// Check exit code from a process handle. Return FALSE on an error also
+BOOL is_running(HANDLE hProcess)
 {
     DWORD dwCode;
 
@@ -203,13 +206,13 @@ BOOL is_running(HANDLE hProcess)
 }
 
 
-//Return None to represent NoSuchProcess, else return NULL for 
-//other exception or the name as a Python string
-PyObject* get_name(long pid) 
+// Return None to represent NoSuchProcess, else return NULL for
+// other exception or the name as a Python string
+PyObject* get_name(long pid)
 {
 	HANDLE h = CreateToolhelp32Snapshot(TH32CS_SNAPPROCESS, 0);
 	PROCESSENTRY32 pe = { 0 };
-	pe.dwSize = sizeof(PROCESSENTRY32);    
+	pe.dwSize = sizeof(PROCESSENTRY32);
 
 	if( Process32First(h, &pe)) {
 	    do {
@@ -219,13 +222,14 @@ PyObject* get_name(long pid)
 			}
 		} while( Process32Next(h, &pe));
 
-        //the process was never found (NoSuchProcess raised later)
+        // the process was never found (NoSuchProcess raised later)
         CloseHandle(h);
         return Py_BuildValue("");
 	}
-    
+
     CloseHandle(h);
-    PyErr_SetString(PyExc_RuntimeError, "Failed to read process name from toolhelp snapshot");
+    PyErr_SetString(PyExc_RuntimeError,
+                    "Failed to read process name from toolhelp snapshot");
     return NULL;
 }
 
@@ -235,7 +239,7 @@ PyObject* get_ppid(long pid)
 {
 	HANDLE h = CreateToolhelp32Snapshot(TH32CS_SNAPPROCESS, 0);
 	PROCESSENTRY32 pe = { 0 };
-	pe.dwSize = sizeof(PROCESSENTRY32);    
+	pe.dwSize = sizeof(PROCESSENTRY32);
 
 	if( Process32First(h, &pe)) {
 	    do {
@@ -245,21 +249,22 @@ PyObject* get_ppid(long pid)
                 return Py_BuildValue("l", pe.th32ParentProcessID);
 			}
 		} while( Process32Next(h, &pe));
-        
-        //the process was never found (NoSuchProcess raised later)
+
+        // the process was never found (NoSuchProcess raised later)
         CloseHandle(h);
         return Py_BuildValue("");
 	}
-    
+
     CloseHandle(h);
-    PyErr_SetString(PyExc_RuntimeError, "Failed to read process ppid from toolhelp snapshot");
+    PyErr_SetString(PyExc_RuntimeError,
+                    "Failed to read process ppid from toolhelp snapshot");
     return NULL;
 }
 
 
 
-/* 
- * returns a Python list representing the arguments for the process 
+/*
+ * returns a Python list representing the arguments for the process
  * with given pid or NULL on error.
  */
 PyObject* get_arg_list(long pid)
@@ -319,38 +324,45 @@ PyObject* get_arg_list(long pid)
     /* print the commandline */
     //printf("%.*S\n", commandLine.Length / 2, commandLineContents);
 
-    //null-terminate the string to prevent wcslen from returning incorrect length
-    //the length specifier is in characters, but commandLine.Length is in bytes
+    // null-terminate the string to prevent wcslen from returning incorrect length
+    // the length specifier is in characters, but commandLine.Length is in bytes
     commandLineContents[(commandLine.Length/sizeof(WCHAR))] = '\0';
-   
-    //attemempt tp parse the command line using Win32 API, fall back on string
-    //cmdline version otherwise
+
+    // attemempt tp parse the command line using Win32 API, fall back on string
+    // cmdline version otherwise
     szArglist = CommandLineToArgvW(commandLineContents, &nArgs);
     if (NULL == szArglist) {
-        //failed to parse arglist
-        //encode as a UTF8 Python string object from WCHAR string
-        argList = Py_BuildValue("N", PyUnicode_AsUTF8String(PyUnicode_FromWideChar(commandLineContents, commandLine.Length/2)));
-    } 
-    
-    
+        // failed to parse arglist
+        // encode as a UTF8 Python string object from WCHAR string
+        argList = Py_BuildValue("N",
+                                PyUnicode_AsUTF8String(
+                                    PyUnicode_FromWideChar(
+                                    commandLineContents, commandLine.Length / 2)
+                                    )
+                                );
+    }
+
+
     else {
-        //arglist parsed as array of UNICODE_STRING, so convert each to Python
-        //string object and add to arg list
+        // arglist parsed as array of UNICODE_STRING, so convert each to Python
+        // string object and add to arg list
         argList = Py_BuildValue("[]");
         for( i=0; i<nArgs; i++) {
-            //printf("%d: %.*S (%d characters)\n", i, wcslen(szArglist[i]), szArglist[i], wcslen(szArglist[i]));
-            arg_from_wchar = PyUnicode_FromWideChar(szArglist[i], wcslen(szArglist[i]));
+            //printf("%d: %.*S (%d characters)\n", i, wcslen(szArglist[i]),
+            //                  szArglist[i], wcslen(szArglist[i]));
+            arg_from_wchar = PyUnicode_FromWideChar(szArglist[i],
+                                                    wcslen(szArglist[i])
+                                                    );
             arg = PyUnicode_AsUTF8String(arg_from_wchar);
             Py_XDECREF(arg_from_wchar);
             PyList_Append(argList, arg);
             Py_XDECREF(arg);
         }
-    } 
-   
+    }
+
     LocalFree(szArglist);
     free(commandLineContents);
     CloseHandle(hProcess);
     return argList;
 }
 
-
