@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Security related functions for Windows platform (Set privileges such as 
+ * Security related functions for Windows platform (Set privileges such as
  * SeDebug), as well as security helper functions.
  */
 
@@ -17,9 +17,7 @@ BOOL SetPrivilege(HANDLE hToken, LPCTSTR Privilege, BOOL bEnablePrivilege)
 
     if(!LookupPrivilegeValue( NULL, Privilege, &luid )) return FALSE;
 
-    //
     // first pass.  get current privilege setting
-    //
     tp.PrivilegeCount = 1;
     tp.Privileges[0].Luid = luid;
     tp.Privileges[0].Attributes = 0;
@@ -35,16 +33,14 @@ BOOL SetPrivilege(HANDLE hToken, LPCTSTR Privilege, BOOL bEnablePrivilege)
 
     if (GetLastError() != ERROR_SUCCESS) return FALSE;
 
-    // 
     // second pass. set privilege based on previous setting
-    //
     tpPrevious.PrivilegeCount = 1;
     tpPrevious.Privileges[0].Luid = luid;
 
     if(bEnablePrivilege) {
         tpPrevious.Privileges[0].Attributes |= (SE_PRIVILEGE_ENABLED);
     }
-    
+
     else {
         tpPrevious.Privileges[0].Attributes ^= (SE_PRIVILEGE_ENABLED &
                 tpPrevious.Privileges[0].Attributes);
@@ -65,16 +61,24 @@ BOOL SetPrivilege(HANDLE hToken, LPCTSTR Privilege, BOOL bEnablePrivilege)
 }
 
 
-int SetSeDebug() 
-{ 
+int SetSeDebug()
+{
     HANDLE hToken;
-    if(!OpenThreadToken(GetCurrentThread(), TOKEN_ADJUST_PRIVILEGES | TOKEN_QUERY, FALSE, &hToken)){
+    if(! OpenThreadToken(GetCurrentThread(),
+                         TOKEN_ADJUST_PRIVILEGES | TOKEN_QUERY,
+                         FALSE,
+                         &hToken)
+                         ){
         if (GetLastError() == ERROR_NO_TOKEN){
             if (!ImpersonateSelf(SecurityImpersonation)){
                 //Log2File("Error setting impersonation [SetSeDebug()]", L_DEBUG);
                 return 0;
             }
-            if(!OpenThreadToken(GetCurrentThread(), TOKEN_ADJUST_PRIVILEGES | TOKEN_QUERY, FALSE, &hToken)){
+            if (!OpenThreadToken(GetCurrentThread(),
+                                 TOKEN_ADJUST_PRIVILEGES | TOKEN_QUERY,
+                                 FALSE,
+                                 &hToken)
+                                 ){
                 //Log2File("Error Opening Thread Token", L_DEBUG);
                 return 0;
             }
@@ -82,7 +86,7 @@ int SetSeDebug()
     }
 
     // enable SeDebugPrivilege (open any process)
-    if(!SetPrivilege(hToken, SE_DEBUG_NAME, TRUE)){
+    if (! SetPrivilege(hToken, SE_DEBUG_NAME, TRUE)){
         //Log2File("Error setting SeDebug Privilege [SetPrivilege()]", L_WARN);
         return 0;
     }
@@ -95,14 +99,22 @@ int SetSeDebug()
 int UnsetSeDebug()
 {
     HANDLE hToken;
-    if(!OpenThreadToken(GetCurrentThread(), TOKEN_ADJUST_PRIVILEGES | TOKEN_QUERY, FALSE, &hToken)){
+    if(! OpenThreadToken(GetCurrentThread(),
+                        TOKEN_ADJUST_PRIVILEGES | TOKEN_QUERY,
+                        FALSE,
+                        &hToken)
+                        ){
         if(GetLastError() == ERROR_NO_TOKEN){
-            if(!ImpersonateSelf(SecurityImpersonation)){
+            if(! ImpersonateSelf(SecurityImpersonation)){
                 //Log2File("Error setting impersonation! [UnsetSeDebug()]", L_DEBUG);
                 return 0;
             }
 
-            if(!OpenThreadToken(GetCurrentThread(), TOKEN_ADJUST_PRIVILEGES | TOKEN_QUERY, FALSE, &hToken)){
+            if(!OpenThreadToken(GetCurrentThread(),
+                                TOKEN_ADJUST_PRIVILEGES | TOKEN_QUERY,
+                                FALSE,
+                                &hToken)
+                                ){
                 //Log2File("Error Opening Thread Token! [UnsetSeDebug()]", L_DEBUG);
                 return 0;
             }
