@@ -5,6 +5,7 @@
  * module methods.
  */
 
+#include <Python.h>
 #include <assert.h>
 #include <errno.h>
 #include <stdbool.h>
@@ -12,7 +13,6 @@
 #include <stdio.h>
 #include <sys/sysctl.h>
 
-#include <Python.h>
 #include "process_info.h"
 
 #define ARGS_ACCESS_DENIED -2
@@ -27,7 +27,7 @@
  * On success, the function returns 0.
  * On error, the function returns a BSD errno value.
  */
-int GetBSDProcessList(kinfo_proc **procList, size_t *procCount) 
+int GetBSDProcessList(kinfo_proc **procList, size_t *procCount)
 {
     int                 err;
     kinfo_proc *        result;
@@ -114,7 +114,7 @@ int GetBSDProcessList(kinfo_proc **procList, size_t *procCount)
 
 /*
  * Borrowed from psi Python System Information project
- * 
+ *
  * Get command arguments and environment variables.
  *
  * Based on code from ps.
@@ -136,7 +136,8 @@ int getcmdargs(long pid, PyObject **exec_path, PyObject **arglist)
 
     *arglist = Py_BuildValue("[]");     /* empty list */
     if (*arglist == NULL) {
-        PyErr_SetString(PyExc_SystemError, "getcmdargs(): failed to build empty list");
+        PyErr_SetString(PyExc_SystemError,
+                        "getcmdargs(): failed to build empty list");
         return -1;
     }
 
@@ -153,7 +154,8 @@ int getcmdargs(long pid, PyObject **exec_path, PyObject **arglist)
     /* Allocate space for the arguments. */
     procargs = (char *)malloc(argmax);
     if (procargs == NULL) {
-        PyErr_SetString(PyExc_MemoryError, "getcmdargs(): Cannot allocate memory for procargs");
+        PyErr_SetString(PyExc_MemoryError,
+                           "getcmdargs(): Cannot allocate memory for procargs");
         return -1;
     }
 
@@ -166,11 +168,11 @@ int getcmdargs(long pid, PyObject **exec_path, PyObject **arglist)
 
     size = (size_t)argmax;
     if (sysctl(mib, 3, procargs, &size, NULL, 0) == -1) {
-        if (22 == errno) { //invalid parameter == access denied for some reason
+        if (22 == errno) { // invalid parameter == access denied for some reason
             free(procargs);
             return -2;       /* Insufficient privileges */
         }
-        
+
         PyErr_SetFromErrno(PyExc_OSError);
         free(procargs);
         return -1;
@@ -187,7 +189,7 @@ int getcmdargs(long pid, PyObject **exec_path, PyObject **arglist)
     /* Skip over the exec_path. */
     for (; cp < &procargs[size]; cp++) {
         if (*cp == '\0') {
-            //End of exec_path reached.
+            // End of exec_path reached.
             break;
         }
     }
@@ -227,7 +229,7 @@ int getcmdargs(long pid, PyObject **exec_path, PyObject **arglist)
                 goto ERROR_C;   /* Exception */
             PyList_Append(*arglist, arg);
             Py_DECREF(arg);
-            
+
             arg_start = cp + 1;
         }
     }
@@ -236,16 +238,16 @@ int getcmdargs(long pid, PyObject **exec_path, PyObject **arglist)
      * sp points to the beginning of the arguments/environment string, and
      * np should point to the '\0' terminator for the string.
      */
-    
+
     if (np == NULL || np == sp) {
-        //Empty or unterminated string.
+        // Empty or unterminated string.
         goto ERROR_B;
     }
 
-    //Make a copy of the string.
-    //asprintf(args, "%s", sp);
+    // Make a copy of the string.
+    // asprintf(args, "%s", sp);
 
-    //Clean up.
+    // Clean up.
     free(procargs);
     return 0;
 
@@ -280,7 +282,7 @@ PyObject* get_arg_list(long pid)
     //printf("pid: %ld\n", pid);
     if (pid < 0) {
         return argList;
-    } 
+    }
 
     r = getcmdargs(pid, &command_path, &cmd_args);
     if (r == 0) {
@@ -297,6 +299,6 @@ PyObject* get_arg_list(long pid)
         return Py_BuildValue("[]");
     }
 
-    return argList; 
+    return argList;
 }
 
